Learn R Programming

NPBBBdesigns (version 1.0.0)

a_value: A-Value of an NPBBB Design for Test-Versus-Control Contrasts

Description

Returns the trace of the variance-covariance matrix of the estimators of the \(v_1 v_2\) elementary test-versus-control contrasts \(\tau_i - \tau_j\) (\(i\) a test treatment, \(j\) a control treatment), that is, the sum of their variances. When the information matrix is completely symmetric within the test set and within the control set (which holds for the A-optimal members of the catalogue) the value is computed in closed form from the canonical quantities \(f_1, f_2, f_4, f_5\) (the average diagonal and off-diagonal entries of the test-test and control-control sub-matrices of \(C\)). This reproduces the values reported in the design catalogues of Vinayaka et al. (2026); see also Hedayat and Majumdar (1984) and Stufken (1988).

Usage

a_value(design, v1, v2)

Value

A single numeric value, the A-value (sum of variances of the

\(v_1 v_2\) test-versus-control elementary contrasts).

Arguments

design

A matrix (or data frame) whose rows are the blocks or sub-blocks and whose entries are the treatment labels. Test treatments must be labelled 1, ..., v1 and control treatments v1 + 1, ..., v1 + v2.

v1

Number of test treatments.

v2

Number of control treatments.

References

Hedayat AS, Majumdar D (1984) A-optimal incomplete block designs for test treatment-control comparisons. Technometrics, 26, 363--370.

Stufken J (1988) On bounds for the efficiency of block designs for comparing test treatments with a control. Journal of Statistical Planning and Inference, 19, 361--372.

Vinayaka, Parsad R, Mandal BN, LN Vinaykumar (2026) Nested partially balanced bipartite block designs for comparing test treatments with multiple controls. Journal of Statistical Theory and Practice. (In press).

Examples

Run this code
d <- rbind(c(1, 2, 5, 6), c(3, 4, 5, 6))
a_value(d, v1 = 4, v2 = 2)

Run the code above in your browser using DataLab