Learn R Programming

NPBBBdesigns (version 1.0.0)

a_value_optimal: A-Value of the A-Optimal Completely Symmetric Reference Design

Description

Computes the smallest attainable A-value (sum of variances of the \(v_1 v_2\) test-versus-control elementary contrasts) within the class of connected (sub-)block designs that are completely symmetric in the test and in the control treatments, for a control replication \(r_0\). This is the benchmark against which the A-efficiency is measured. The expression is the nested-design analogue of the Hedayat-Majumdar / Stufken optimal A-value; see Vinayaka et al. (2026).

Usage

a_value_optimal(v1, v2, b, k, r0)

Value

A single numeric value, the optimal (minimum) A-value.

Arguments

v1

Number of test treatments.

v2

Number of control treatments.

b

Number of blocks (or sub-blocks) in the classification.

k

Block (or sub-block) size.

r0

Replication of each control treatment in the classification.

References

Hedayat AS, Majumdar D (1984) A-optimal incomplete block designs for test treatment-control comparisons. Technometrics, 26, 363--370.

Stufken J (1988) On bounds for the efficiency of block designs for comparing test treatments with a control. Journal of Statistical Planning and Inference, 19, 361--372.

Vinayaka, Parsad R, Mandal BN, LN Vinaykumar (2026) Nested partially balanced bipartite block designs for comparing test treatments with multiple controls. Journal of Statistical Theory and Practice. (In press).

Examples

Run this code
# Optimal block-classification A-value for an NPBBB with v1 = 9, v2 = 2
a_value_optimal(v1 = 9, v2 = 2, b = 6, k = 10, r0 = 12)

Run the code above in your browser using DataLab