Learn R Programming

NPBBBdesigns (version 1.0.0)

construct_method5: Construct an NPBBB Design by Expanding the Size-4 Blocks of a PBIB Design

Description

Implements Method 5 of Vinayaka et al. (2026) (specific to v2 = 2). Each block \((x_1, x_2, x_3, x_4)\) of a PBIB design with block size 4 is expanded, with the two controls \(0_1, 0_2\), into four blocks of size 6 (each consisting of two sub-blocks of size 3): the \(i\)-th block places \(x_i\) with both controls in one sub-block and the remaining three treatments in the other.

Usage

construct_method5(pbib_blocks)

Value

An object of class "npbbb" with v2 = 2: a list with the following components:

  • method: a character string naming the construction used.

  • v1, v2: numbers of test and control treatments.

  • parameters: a list of the design parameters v1, v2, b1, b2, r1, r2, k1, k2, q.

  • block_design: an integer matrix with b1 rows and k1 columns; each row is a block written as its concatenated sub-blocks.

  • subblock_design: an integer matrix with b2 rows and k2 columns; each row is a sub-block.

  • E1, E2: block and sub-block A-efficiencies.

  • efficiency: an object of class "npbbb_efficiency" holding the underlying A-values and optimal references.

Arguments

pbib_blocks

A list of integer vectors of length 4, the blocks of a PBIB design with test treatments labelled 1, ..., v1.

References

Vinayaka, Parsad R, Mandal BN, LN Vinaykumar (2026) Nested partially balanced bipartite block designs for comparing test treatments with multiple controls. Journal of Statistical Theory and Practice. (In press).

Examples

Run this code
# Singular GD design S1: v = 6, b = 3, k = 4
s1 <- list(c(1,2,3,4), c(1,2,5,6), c(3,4,5,6))
d <- construct_method5(s1)
d

Run the code above in your browser using DataLab