Learn R Programming

NPBBBdesigns (version 1.0.0)

construct_method6: Construct an NPBBB Design by Expanding the Size-2 Blocks of a PBIB Design

Description

Implements Method 6 of Vinayaka et al. (2026) (specific to v2 = 2). Each block \((x_1, x_2)\) of a PBIB design with block size 2 is expanded, with the two controls \(0_1, 0_2\), into three blocks of size 4 (two sub-blocks of size 2): \([(x_1, x_2);(0_1, 0_2)]\), \([(x_1, 0_1);(x_2, 0_2)]\) and \([(x_1, 0_2);(x_2, 0_1)]\).

Usage

construct_method6(pbib_blocks)

Value

An object of class "npbbb" with v2 = 2: a list with the following components:

  • method: a character string naming the construction used.

  • v1, v2: numbers of test and control treatments.

  • parameters: a list of the design parameters v1, v2, b1, b2, r1, r2, k1, k2, q.

  • block_design: an integer matrix with b1 rows and k1 columns; each row is a block written as its concatenated sub-blocks.

  • subblock_design: an integer matrix with b2 rows and k2 columns; each row is a sub-block.

  • E1, E2: block and sub-block A-efficiencies.

  • efficiency: an object of class "npbbb_efficiency" holding the underlying A-values and optimal references.

Arguments

pbib_blocks

A list of integer vectors of length 2, the blocks of a PBIB design with test treatments labelled 1, ..., v1.

References

Vinayaka, Parsad R, Mandal BN, LN Vinaykumar (2026) Nested partially balanced bipartite block designs for comparing test treatments with multiple controls. Journal of Statistical Theory and Practice. (In press).

Examples

Run this code
# Semi-regular GD design SR1: v = 4, b = 4, k = 2
sr1 <- list(c(1,3), c(1,4), c(2,3), c(2,4))
d <- construct_method6(sr1)
d

Run the code above in your browser using DataLab