Learn R Programming

NPBBBdesigns (version 1.0.0)

npbbb_efficiency: A-Efficiency of an NPBBB Design

Description

Evaluates the A-efficiency of a nested partially balanced bipartite block design separately for its block and sub-block classifications. For each classification the A-efficiency is $$E = A^{\mathrm{opt}} / A,$$ the ratio of the A-value of the A-optimal completely symmetric reference design to the A-value of the design under study. A value of 1 means the design is A-optimal for that classification. For more details see Vinayaka et al. (2026).

Usage

npbbb_efficiency(block_design, subblock_design, v1, v2)

Value

An object of class "npbbb_efficiency": a list with the following components:

  • E1: block-classification A-efficiency.

  • E2: sub-block-classification A-efficiency.

  • A1, A2: A-values of the design under study (block and sub-block classifications, respectively).

  • A1_opt, A2_opt: A-values of the corresponding A-optimal completely symmetric reference designs.

  • v1, v2: numbers of test and control treatments.

Arguments

block_design

A matrix whose rows are the blocks (each block being the concatenation of its sub-blocks) and whose entries are treatment labels 1, ..., v1 (test) and v1 + 1, ..., v1 + v2 (control).

subblock_design

A matrix whose rows are the sub-blocks, with the same labelling convention.

v1

Number of test treatments.

v2

Number of control treatments.

References

Hedayat AS, Majumdar D (1984) A-optimal incomplete block designs for test treatment-control comparisons. Technometrics, 26, 363--370.

Stufken J (1988) On bounds for the efficiency of block designs for comparing test treatments with a control. Journal of Statistical Planning and Inference, 19, 361--372.

Vinayaka, Parsad R, Mandal BN, LN Vinaykumar (2026) Nested partially balanced bipartite block designs for comparing test treatments with multiple controls. Journal of Statistical Theory and Practice. (In press).

Examples

Run this code
d <- construct_method4(m = 3, n = 2, v2 = 2)
npbbb_efficiency(d$block_design, d$subblock_design, v1 = d$v1, v2 = d$v2)

Run the code above in your browser using DataLab