Learn R Programming

NPBBBdesigns (version 1.0.0)

print.npbbb_efficiency: Print Method for NPBBB Efficiency Objects

Description

Prints the block and sub-block A-efficiencies of a nested partially balanced bipartite block design held in an object of class "npbbb_efficiency".

Usage

# S3 method for npbbb_efficiency
print(x, digits = 4, ...)

Value

The object x, invisibly.

Arguments

x

An object of class "npbbb_efficiency", as returned by npbbb_efficiency.

digits

Number of significant digits used when printing the A-values and A-efficiencies.

...

Further arguments passed to or from other methods.

Examples

Run this code
d <- construct_method4(m = 3, n = 2, v2 = 2)
print(d$efficiency)

Run the code above in your browser using DataLab