info_matrix: Information Matrix of a (Sub-)Block Design for Test-Versus-Control Comparisons
Description
Computes the reduced (treatment) information matrix
\(C = R - N K^{-1} N^\prime\) for a single classification (blocks or
sub-blocks) of a nested partially balanced bipartite block (NPBBB) design.
Here \(R\) is the diagonal matrix of treatment replications, \(N\) is the
treatment-by-(sub-)block incidence matrix and \(K\) is the diagonal matrix
of (sub-)block sizes. Control treatments may occur more than once in a
(sub-)block (for example, designs obtained by merging rows of a
group-divisible scheme); such multiplicities are counted in \(N\) so that
\(C\) is the correct information matrix under the homoscedastic
fixed-effects nested model. For more details see Vinayaka et al. (2026).
Usage
info_matrix(design, v1, v2)
Value
A numeric (v1 + v2) by (v1 + v2) information matrix
\(C\).
Arguments
design
A matrix (or data frame) whose rows are the blocks or sub-blocks
and whose entries are the treatment labels. Test treatments must be labelled
1, ..., v1 and control treatments v1 + 1, ..., v1 + v2.
v1
Number of test treatments.
v2
Number of control treatments.
References
Vinayaka, Parsad R, Mandal BN, LN Vinaykumar (2026) Nested partially balanced bipartite block designs for comparing test treatments with multiple controls. Journal of Statistical Theory and Practice. (In press).