powered by
Returns the total number of experimental units of a nested partially balanced bipartite block design, \(N = b_2 k_2 = b_1 k_1\).
n_units(x)
A single numeric value, the total number of experimental units
\(N = b_2 k_2 = b_1 k_1\).
An object of class "npbbb", as returned by the construct_method* functions.
"npbbb"
construct_method*
d <- construct_method4(m = 3, n = 2, v2 = 2) n_units(d)
Run the code above in your browser using DataLab