powered by
Prints a nested partially balanced bipartite block design: its construction method, design parameters, block and sub-block A-efficiencies and, optionally, the full block layout with controls displayed as 0_1, 0_2, ....
0_1, 0_2, ...
# S3 method for npbbb print(x, digits = 4, show_layout = TRUE, ...)
The object x, invisibly.
x
An object of class "npbbb", as returned by the construct_method* functions.
"npbbb"
construct_method*
Number of significant digits used when printing the A-efficiencies.
Logical; if TRUE the block and sub-block layouts are printed.
TRUE
Further arguments passed to or from other methods.
d <- construct_method4(m = 3, n = 2, v2 = 2) print(d) print(d, show_layout = FALSE)
Run the code above in your browser using DataLab