powered by
Prints the block and sub-block A-efficiencies of a nested partially balanced bipartite block design held in an object of class "npbbb_efficiency".
"npbbb_efficiency"
# S3 method for npbbb_efficiency print(x, digits = 4, ...)
The object x, invisibly.
x
An object of class "npbbb_efficiency", as returned by npbbb_efficiency.
npbbb_efficiency
Number of significant digits used when printing the A-values and A-efficiencies.
Further arguments passed to or from other methods.
d <- construct_method4(m = 3, n = 2, v2 = 2) print(d$efficiency)
Run the code above in your browser using DataLab